0.9.9 API documentation: vector_uint2_precision.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Typedefs
vector_uint2_precision.hpp File Reference

Core features More...

Go to the source code of this file.

## Typedefs
typedef vec< 2, unsigned int, highp > | highp_uvec2
| 2 components vector of high qualifier unsigned integer numbers. More...
typedef vec< 2, unsigned int, lowp > | lowp_uvec2
| 2 components vector of low qualifier unsigned integer numbers. More...
typedef vec< 2, unsigned int, mediump > | mediump_uvec2
| 2 components vector of medium qualifier unsigned integer numbers. More...

## Detailed Description

Core features

Definition in file vector_uint2_precision.hpp.